# PatchedTopicRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**guid** | **str** |  | [optional] 
**topic_type** | **str, none_type** |  | [optional] 
**topic_status** | **str, none_type** |  | [optional] 
**title** | **str** |  | [optional] 
**priority** | **str, none_type** |  | [optional] 
**labels** | **[str, none_type]** |  | [optional] 
**creation_date** | **datetime** |  | [optional] 
**creation_author** | **str, none_type** |  | [optional] 
**modified_author** | **str, none_type** |  | [optional] 
**assigned_to** | **str, none_type** |  | [optional] 
**reference_links** | **[str], none_type** |  | [optional] 
**stage** | **str, none_type** |  | [optional] 
**description** | **str, none_type** |  | [optional] 
**due_date** | **datetime, none_type** |  | [optional] 
**ifcs** | **[int]** | DEPRECATED: Use &#39;models&#39; instead | [optional] 
**models** | **[int]** |  | [optional] 
**format** | **str** |  | [optional] 
**index** | **int, none_type** |  | [optional] 
**project** | **int** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


